SystemOrganization addCategory: #SourceCity!

Object subclass: #CityImporter
	instanceVariableNames: 'classes methods packages city districts'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SourceCity'!

!CityImporter commentStamp: '<historical>' prior: 0!
I'm responsible for populating a city from a model (usually a ring model)!

!CityImporter methodsFor: 'import' stamp: 'DouailleErwan 4/2/2012 15:44'!
basicDistrict: aPackageName

	 | d |
	d := District new model: (self packageNamed: aPackageName).
	city add: d.
	^d
	
	! !

!CityImporter methodsFor: 'accessing' stamp: 'DouailleErwan 4/2/2012 14:39'!
city

	^city! !

!CityImporter methodsFor: 'import' stamp: 'DouailleErwan 4/2/2012 14:38'!
cityNamed: aName withPackageNames: aCol

	city := City new name: aName.
	aCol do: [:each |
				self importPackageAsDistrict: each ]! !

!CityImporter methodsFor: 'import' stamp: 'DouailleErwan 4/2/2012 15:44'!
ensureDistrict: aPackageName

	^ districts 
			at: aPackageName 
			ifAbsentPut: [ self basicDistrict: aPackageName].
			
						! !

!CityImporter methodsFor: 'import' stamp: 'DouailleErwan 4/2/2012 15:43'!
importPackageAsDistrict: aPackageName

	| ctPack |
	ctPack := self ensureDistrict: aPackageName.
	! !

!CityImporter methodsFor: 'initialize-release' stamp: 'DouailleErwan 4/2/2012 14:34'!
initialize

	super initialize.
	districts := Dictionary new.! !

!CityImporter methodsFor: 'utils' stamp: 'DouailleErwan 4/2/2012 14:28'!
packageNamed: aString

	^ RPackageOrganizer default packageNamed: aString! !

Object subclass: #CityObject
	instanceVariableNames: 'model'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SourceCity'!

!CityObject commentStamp: '<historical>' prior: 0!
I'm an abstract class root of the city elements!

CityObject subclass: #Building
	instanceVariableNames: 'size aColor'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SourceCity'!

!Building commentStamp: '<historical>' prior: 0!
A Building is the level abstraction.!

CityObject subclass: #City
	instanceVariableNames: 'districts name'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SourceCity'!

!City commentStamp: '<historical>' prior: 0!
A City represents the largest model element. It contains a list of districts.!

!City methodsFor: 'adding' stamp: 'DouailleErwan 4/2/2012 14:13'!
add: aDistrict

	districts add: aDistrict.
	^ aDistrict! !

!City methodsFor: 'accessing' stamp: 'DouailleErwan 4/2/2012 14:36'!
districts

	^ districts! !

!City methodsFor: 'testing' stamp: 'DouailleErwan 4/2/2012 14:48'!
hasDistrictNamed: aString
	
	^ districts anySatisfy: [:each | each model name = aString]! !

!City methodsFor: 'initialize-release' stamp: 'DouailleErwan 4/2/2012 14:12'!
initialize

	super initialize.
	districts := OrderedCollection new! !

!City methodsFor: 'accessing' stamp: 'DouailleErwan 4/2/2012 14:38'!
name
	^ name! !

!City methodsFor: 'accessing' stamp: 'DouailleErwan 4/2/2012 14:38'!
name1
	^ name! !

!City methodsFor: 'accessing' stamp: 'DouailleErwan 4/2/2012 14:38'!
name: anObject
	name := anObject! !

!CityObject methodsFor: 'accessing' stamp: 'DouailleErwan 4/2/2012 14:10'!
model 
	"Returns the model associated with the receiver, it can be a class, package...."
	
	^model! !

!CityObject methodsFor: 'accessing' stamp: 'DouailleErwan 4/2/2012 14:10'!
model: aModel
	"Set the model associated with the receiver, it can be a class, package...."
	
	model := aModel! !

CityObject subclass: #District
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SourceCity'!

!District commentStamp: '<historical>' prior: 0!
A District is a secondary city abstractions!

!District methodsFor: 'printing' stamp: 'DouailleErwan 4/2/2012 14:46'!
printOn: aStream

	super printOn: aStream.
	model ifNotNil: [ aStream 
					nextPutAll: ' ('; 
					nextPutAll: model name ; 
					nextPutAll: ')']! !

TestCase subclass: #CityImporterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SourceCity'!

!CityImporterTest methodsFor: 'tests' stamp: 'DouailleErwan 4/2/2012 15:40'!
testImportPackageAsDistrict
	"self debug: #testImportPackageAsDistrict"
	
	| cimport |
	cimport := CityImporter new.
	cimport cityNamed: 'CodCT' withPackageNames: #('AST-Core' ).
	self assert: cimport city districts size =1.
	self assert: (cimport city hasDistrictNamed: #'AST-Core').
	! !

!CityImporterTest methodsFor: 'tests' stamp: 'DouailleErwan 4/2/2012 15:42'!
testImportPackageAsDistrictNoDuplicate
	"self debug: #testImportPackageAsDistrictNoDuplicate"
	
	| cimport |
	cimport := CityImporter new.
	cimport cityNamed: 'CodCT' withPackageNames: #('AST-Core' 'SourceCity' 'AST-Core').
	self assert: cimport city districts size = 2.
	self assert: (cimport city hasDistrictNamed: #'AST-Core').
	! !
